==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleInformation__5fgu__5fIN.h <==
// public class gnu.java.locale.LocaleInformation_gu_IN

// class file dependencies
// @dep_class 98130621499eb94f gnu_java_locale_LocaleInformation__5fgu__5fIN
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fgu__5fIN_H_
#define _JC_gnu_java_locale_LocaleInformation__5fgu__5fIN_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$refs	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vmethods	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtable	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtype	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$fields_struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object *);
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vmethods	gnu_java_locale_LocaleInformation__5fgu__5fIN;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$refs {
    _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_refs	gnu_java_locale_LocaleInformation__5fgu__5fIN;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_nonrefs	gnu_java_locale_LocaleInformation__5fgu__5fIN;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object {
	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtype _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fgu__5fIN, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fgu__5fIN_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleInformation__5fgu__5fIN.h <==
// public class gnu.java.locale.LocaleInformation_gu_IN

// class file dependencies
// @dep_class e71e981aaa15235f gnu_java_locale_LocaleInformation__5fgu__5fIN
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fgu__5fIN_H_
#define _JC_gnu_java_locale_LocaleInformation__5fgu__5fIN_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$refs	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vmethods	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtable	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtype	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$fields_struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vmethods	gnu_java_locale_LocaleInformation__5fgu__5fIN;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$refs {
    _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_refs	gnu_java_locale_LocaleInformation__5fgu__5fIN;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$sub_nonrefs	gnu_java_locale_LocaleInformation__5fgu__5fIN;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$object {
	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$vtype _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fgu__5fIN, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fgu__5fIN$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fgu__5fIN_H_ */
